@@ -3,7 +3,7 @@ package App::FfmpegUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-03'; # DATE
 our $DIST = 'App-FfmpegUtils'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,9 +45,16 @@ $SPEC{reencode_video} = {
     summary => 'Re-encode video (using ffmpeg and H.264 codec)',
     description => <<'_',
 
-This utility runs ffmpeg to re-encode your video files. Usually used to reduce
-the file size (and optionally video width/height) so they are smaller, while
-minimizing quality loss.
+This utility runs ffmpeg to re-encode your video files. It is a wrapper to
+simplify invocation of ffmpeg. It selects the appropriate ffmpeg options for
+you, allows you to specify multiple files, and picks appropriate output
+filenames. It also sports a `--dry-run` option to let you see ffmpeg options to
+be used without actually running ffmpeg.
+
+This utility is usually used to reduce the file size (and optionally video
+width/height) of videos so they are smaller, while minimizing quality loss. The
+default setting is roughly similar to how Google Photos encodes videos (max
+1080p).
 
 The default settings are:
 
@@ -55,8 +62,11 @@ The default settings are:
     -preset veryslow (to get the best compression rate, but with the slowest encoding time)
     -crf 28 (0-51, subjectively sane is 18-28, 18 ~ visually lossless, 28 ~ visually acceptable)
 
-when a downsizing is requested (using the `--downsize-to` option), the `-vf
-scale` option is used and this utility calculate a valid size for ffmpeg.
+when a downsizing is requested (using the `--downsize-to` option), this utility
+first checks each input video if it is indeed larger than the requested final
+size. If it is, then the `-vf scale` option is added. This utility also
+calculates a valid size for ffmpeg, since using `-vf scale=-1:720` sometimes
+results in failure due to odd number.
 
 Audio streams are copied, not re-encoded.
 
@@ -76,12 +86,49 @@ _
             schema => ['int*', between=>[0,51]],
         },
         downsize_to => {
-            schema => ['str*', in=>['480p', '720p', '1080p']],
+            schema => ['str*', in=>['', '480p', '720p', '1080p']],
+            default => '1080p',
+            description => <<'_',
+
+Downsizing will only be done if the input video is indeed larger then the target
+downsize.
+
+To disable downsizing, set `--downsize-to` to '' (empty string), or specify on
+`--dont-downsize` on the CLI.
+
+_
+            cmdline_aliases => {
+                dont_downsize => {summary=>"Alias for --downsize-to ''", is_flag=>1, code=>sub {$_[0]{downsize_to} = ''}},
+                no_downsize   => {summary=>"Alias for --downsize-to ''", is_flag=>1, code=>sub {$_[0]{downsize_to} = ''}},
+            },
         },
     },
     features => {
         dry_run => 1,
     },
+    examples => [
+        {
+            summary => 'The default setting is to downsize to 1080p',
+            src => 'reencode-video *',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Do not downsize',
+            src => 'reencode-video --dont-downsize *',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Downsize to 480p but make it "visually lossless"',
+            src => 'reencode-video --downsize-to 480p --crf 18 *',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub reencode_video {
     require File::Which;
@@ -186,7 +233,7 @@ App::FfmpegUtils - Utilities related to ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.001 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2020-06-03.
+This document describes version 0.002 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2020-06-03.
 
 =head1 FUNCTIONS
 
@@ -199,9 +246,16 @@ Usage:
 
 Re-encode video (using ffmpeg and H.264 codec).
 
-This utility runs ffmpeg to re-encode your video files. Usually used to reduce
-the file size (and optionally video width/height) so they are smaller, while
-minimizing quality loss.
+This utility runs ffmpeg to re-encode your video files. It is a wrapper to
+simplify invocation of ffmpeg. It selects the appropriate ffmpeg options for
+you, allows you to specify multiple files, and picks appropriate output
+filenames. It also sports a C<--dry-run> option to let you see ffmpeg options to
+be used without actually running ffmpeg.
+
+This utility is usually used to reduce the file size (and optionally video
+width/height) of videos so they are smaller, while minimizing quality loss. The
+default setting is roughly similar to how Google Photos encodes videos (max
+1080p).
 
 The default settings are:
 
@@ -209,8 +263,11 @@ The default settings are:
  -preset veryslow (to get the best compression rate, but with the slowest encoding time)
  -crf 28 (0-51, subjectively sane is 18-28, 18 ~ visually lossless, 28 ~ visually acceptable)
 
-when a downsizing is requested (using the C<--downsize-to> option), the C<-vf
-scale> option is used and this utility calculate a valid size for ffmpeg.
+when a downsizing is requested (using the C<--downsize-to> option), this utility
+first checks each input video if it is indeed larger than the requested final
+size. If it is, then the C<-vf scale> option is added. This utility also
+calculates a valid size for ffmpeg, since using C<-vf scale=-1:720> sometimes
+results in failure due to odd number.
 
 Audio streams are copied, not re-encoded.
 
@@ -233,7 +290,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<crf> => I<int>
 
-=item * B<downsize_to> => I<str>
+=item * B<downsize_to> => I<str> (default: "1080p")
+
+Downsizing will only be done if the input video is indeed larger then the target
+downsize.
+
+To disable downsizing, set C<--downsize-to> to '' (empty string), or specify on
+C<--dont-downsize> on the CLI.
 
 =item * B<ffmpeg_path> => I<filename>
 
